# Level screen class

import pygame
from pygame.locals import *

import tools, parameters, Button, Vehicle, Wall, Lamp

class Level:
    """level screen"""
    title = ''
    enties = []
    buttons = []
    sprite_lst = []
    vehicle = None
    sprites = []  

    wall_color = (90, 90, 90)
    plate_color = (0, 150, 0)
    wall_lst = []

    lamp_lst = []

    in_hand_lamp = None

    win_plate = None
    win_rect = None

    state = 'play'

    win_text = None

    level_number = -1
    
    def __init__(self, title, number):

        self.title = title

        self.level_number = number
        

        # Title text
        self.title_text = Button.Font(None, (5, 5), 18, title)
        self.title_text.rect.topleft = (5,5)

        # win text
        self.win_text = Button.Font(None,(330,70), 24, 'Level complete!')

        # buttons
        self.next_level_button = Button.Button((750, 500), 'next level')
        self.prev_level_button = Button.Button((750, 550), 'prev level')
        self.start_veh_button = Button.Button((750,400),'Play')
        self.reset_button = Button.Button((750,350),'reset')
                                          
        # walls
        top_wall = Wall.Wall((0,20,650,10), self.wall_color)
        bottom_wall = Wall.Wall((0,590,650,10), self.wall_color)
        right_wall = Wall.Wall((640,30,10,570), self.wall_color)
        left_wall = Wall.Wall((0,20,10,590), self.wall_color)
        

        # append everyting
        self.enties.append(self.next_level_button)
        self.enties.append(self.title_text)
        #self.enties.append(win_text)
        self.enties.append(self.start_veh_button)
        self.enties.append(self.prev_level_button)
        self.enties.append(self.reset_button)

        self.buttons.append(self.next_level_button)
        self.buttons.append(self.start_veh_button)
        self.buttons.append(self.prev_level_button)
        self.buttons.append(self.reset_button)

        self.sprite_lst.append(top_wall)
        self.sprite_lst.append(right_wall)
        self.sprite_lst.append(bottom_wall)
        self.sprite_lst.append(left_wall)

        self.wall_lst = [top_wall, right_wall, bottom_wall,left_wall]
        
    def init_draw(self):
        for ent in self.enties:
            ent.draw()
        # draw win plate
        tools.background.blit(self.win_plate, self.win_rect)

    def add_wall(self, rect):
        wall = Wall.Wall(rect, self.wall_color)
        self.sprite_lst.append(wall)
        self.wall_lst = self.wall_lst + [wall]
        
    def clicked(self, pos):
        # check buttons
        
        for but in self.buttons:
            if but.texty == 'next level':
                if but.rect.collidepoint(pos):
                    tools.change_level = 1
                    tools.group.remove(self.vehicle)
                    #self.vehicle.kill()

                    tools.group.remove(self.lamp_lst)
                    tools.group.remove(self.wall_lst)
                    for lamp in self.lamp_lst:
                        lamp.kill()
                    for wall in self.wall_lst:
                        wall.kill()

                    # war for the font issue
                    #tmp_img, tmp_rect = tools.get_solid(self.title_text.rect.size, parameters.BACKGROUND_COLOR)
                    #tools.background.blit(tmp_img, (0,0))
                    #tools.screen.blit(tools.background, (0,0))
                    #pygame.display.flip()
                    #tools.group.empty()
            elif but.texty == 'prev level':
                if self.level_number == 0: pass
                elif but.rect.collidepoint(pos):
                    tools.next_level = tools.next_level - 1
                    tools.change_level = 1
                    tools.group.remove(self.vehicle)
                    #self.vehicle.kill()

                    tools.group.remove(self.lamp_lst)
                    tools.group.remove(self.wall_lst)
                    for lamp in self.lamp_lst:
                        lamp.kill()
                    for wall in self.wall_lst:
                        wall.kill()
                    
            else:
                but.check_clicked(pos)

        # check lamps
        for lamp in self.lamp_lst:
            if lamp.check_clicked(pos):
                self.in_hand_lamp = lamp
                break

    def unclicked(self, pos):
        if self.in_hand_lamp != None:
            self.in_hand_lamp.rect.center = pos
            self.in_hand_lamp.state = 'dropped'
            self.in_hand_lamp = None
        
    def set_ch_button_action(self):
        self.start_veh_button.action = (tools.start_veh, self.vehicle)
        self.next_level_button.action = (tools.change_level, 'level')
        self.prev_level_button.action = (tools.change_level, 'level')
        self.reset_button.action = (tools.reset, self)

    def init_vehicle(self, position, direction):
        self.vehicle = Vehicle.Vehicle(position, direction)
        self.sprite_lst.append(self.vehicle)

    def init_sprites(self):
        tools.group.add(self.vehicle)
        tools.group.add(self.wall_lst)
        tools.group.add(self.lamp_lst)
        #tools.group = pygame.sprite.RenderPlain(self.sprite_lst)
        
    def update(self):

        # check for win
        if self.win_rect.contains(self.vehicle.rect):
            self.vehicle.state = 'stop'
            self.state = 'won'
            self.win_text.draw()
        # check for wall collision
        for wall in self.wall_lst:
            if wall.collide(self.vehicle):
                self.vehicle.state = 'stop'

        # check for lamp in 'sight'
        self.vehicle.chk_prox(self.lamp_lst)
        
        tools.group.draw(tools.screen)
        tools.group.update()

    def add_lamp(self, pos):
        lamp = Lamp.Lamp(pos)
        self.sprite_lst = self.sprite_lst+[lamp]
        self.lamp_lst = self.lamp_lst+[lamp]

    # reset level
    def reset(self):
        self.vehicle.reset()

        if self.state == 'won':
            self.win_text.remove()

    def add_win_plate(self, pos):
        
        self.win_plate, self.win_rect = tools.get_solid((50,50), self.plate_color)
        self.win_rect.center = pos
